aboutsummaryrefslogtreecommitdiffstats
path: root/phpBB/phpbb/hook/finder.php
diff options
context:
space:
mode:
Diffstat (limited to 'phpBB/phpbb/hook/finder.php')
-rw-r--r--phpBB/phpbb/hook/finder.php4
1 files changed, 2 insertions, 2 deletions
diff --git a/phpBB/phpbb/hook/finder.php b/phpBB/phpbb/hook/finder.php
index 7b0412f733..3f9758211d 100644
--- a/phpBB/phpbb/hook/finder.php
+++ b/phpBB/phpbb/hook/finder.php
@@ -31,9 +31,9 @@ class phpbb_hook_finder
*
* @param string $phpbb_root_path Path to the phpbb root directory
* @param string $php_ext php file extension
* @param phpbb_cache_driver_interface $cache A cache instance or null
*/
- public function __construct($phpbb_root_path, $php_ext, phpbb_cache_driver_interface $cache = null)
+ public function __construct($phpbb_root_path, $php_ext, phpbb_cache_driver_driver_interface $cache = null)
{
$this->phpbb_root_path = $phpbb_root_path;
$this->cache = $cache;
@@ -31,9 +31,9 @@ class phpbb_hook_finder
* @param string $phpbb_root_path Path to the phpbb root directory
* @param string $php_ext php file extension
- * @param phpbb_cache_driver_interface $cache A cache instance or null
+ * @param phpbb_cache_driver_driver_interface $cache A cache instance or null
*/